# Password Rules
### On this page
  * [Regular Password Rules](https://help.sap.com/docs/leanix/ea/password-rules#regular-password-rules)
  * [Strict Password Rules](https://help.sap.com/docs/leanix/ea/password-rules#strict-password-rules)


Rules for workspace passwords.
We offer two options for password rules: regular and strict. The choice between regular and strict rules largely depends on your organization's security requirements.
